==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/2a/2af32720b9f5911123afc3be36cff677.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php */
class __TwigTemplate_c945c14739bdd21bb8ac965fe215dc19 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CacheBundle\\Cache\\Adapter;

use Symfony\\Component\\Cache\\Adapter\\TagAwareAdapter;

class FilesystemTagAwareAdapter extends TagAwareAdapter
{
    public function __construct(?string \$prefix, int \$lifetime = 0, string \$directory = null)
    {
        \$prefix = 'app_cache_'.\$prefix;

        parent::__construct(
            new \\Symfony\\Component\\Cache\\Adapter\\FilesystemAdapter(\$prefix, \$lifetime, \$directory),
            new \\Symfony\\Component\\Cache\\Adapter\\FilesystemAdapter(\$prefix.'_tags')
        );
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php", "/var/www/html/mauticGIT-Test/app/bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/2a/2af32720b9f5911123afc3be36cff677.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php */
class __TwigTemplate_c945c14739bdd21bb8ac965fe215dc19 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CacheBundle\\Cache\\Adapter;

use Symfony\\Component\\Cache\\Adapter\\TagAwareAdapter;

class FilesystemTagAwareAdapter extends TagAwareAdapter
{
    public function __construct(?string \$prefix, int \$lifetime = 0, string \$directory = null)
    {
        \$prefix = 'app_cache_'.\$prefix;

        parent::__construct(
            new \\Symfony\\Component\\Cache\\Adapter\\FilesystemAdapter(\$prefix, \$lifetime, \$directory),
            new \\Symfony\\Component\\Cache\\Adapter\\FilesystemAdapter(\$prefix.'_tags')
        );
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php", "/var/www/html/production-demo/app/bundles/CacheBundle/Cache/Adapter/FilesystemTagAwareAdapter.php");
    }
}
